==> was-plugin-1.2.2.jar: com/xebialabs/deployit/plugin/was/step/start-server.py <==
#
# Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to  (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#


import sys
from com.ibm.ws.scripting import ScriptingException

servername = sys.argv[0]
nodename = sys.argv[1]

print "Deployit INFO: Starting server: " + servername + " on node: " + nodename
try:
    AdminControl.startServer(servername, nodename)
    AdminConfig.save()
    print "Deployit INFO: Started server: " + servername
except ScriptingException:
    message = "" + str(sys.exc_info()[1] )
    pos = message.find("is already running on node")
    if pos != -1:
        print "Deployit INFO: server: " + servername + " is already running on node " + nodename
    else:
        print "Deployit INFO: oops, an error occurred while starting a server: " + servername + " on node: "+ nodename + " error: " +str(sys.exc_info()[1] )
        raise

sys.exit(0)

==> was-plugin-1.3.2.1.jar: com/xebialabs/deployit/plugin/was/step/start-server.py <==
#
# Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys
from com.ibm.ws.scripting import ScriptingException

servername = sys.argv[0]
nodename = sys.argv[1]

print "Starting server " + servername + " on node " + nodename
try:
    AdminControl.startServer(servername, nodename)
except ScriptingException:
    message = "" + str(sys.exc_info()[1] )
    pos = message.find("is already running on node")
    if pos != -1:
        print "Server:" + servername + " is already running on node " + nodename
    else:
        print "An error occurred while starting a server " + servername + " on node "+ nodename + ": " +str(sys.exc_info()[1] )
        raise
